[Pkg-mozext-commits] [firebug] 22/68: FBTest: fix for dom/6283

David Prévot taffit at moszumanska.debian.org
Mon Mar 31 22:45:51 UTC 2014


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to tag fbtest-1.11.4
in repository firebug.

commit 700b91277656cf50b5a67d789307dfa9dba2af20
Author: Jan Odvarko <odvarko at gmail.com>
Date:   Mon Apr 8 15:47:44 2013 +0200

    FBTest: fix for dom/6283
---
 tests/content/dom/6283/issue6283.js | 14 +++++++++++---
 1 file changed, 11 insertions(+), 3 deletions(-)

diff --git a/tests/content/dom/6283/issue6283.js b/tests/content/dom/6283/issue6283.js
index 20a202c..f9f08bd 100644
--- a/tests/content/dom/6283/issue6283.js
+++ b/tests/content/dom/6283/issue6283.js
@@ -12,7 +12,7 @@ function runTest()
             FBTest.executeContextMenuCommand(FW.Firebug.chrome.$("fbLocationList"),
                 "InspectIndomPanel", function()
             {
                 // xxxHonza, xxxsz: hack that fixes this text on Mac. The panel can 
                 // be selected asynchronously.
                 setTimeout(function() {
                     onInspect();
@@ -36,13 +36,20 @@ function onInspect()
 
         for (var i=0; i<props.length; i++)
         {
-            if (props[i].textContent == "cssRules")
+            var propName = props[i].lastChild.textContent
+            if (propName == "cssRules")
             {
                 prop = props[i];
                 break;
             }
         }
 
+        if (!FBTest.ok(prop, "cssRules property must be there"))
+        {
+            FBTest.testDone("issue5247.DONE");
+            return;
+        }
+
         var config = {tagName: "tr", classes: "memberRow ordinalRow"};
         FBTest.waitForDisplayedElement("dom", config, function(row)
         {
@@ -51,7 +58,8 @@ function onInspect()
             var cssRuleValue = FW.FBL.getAncestorByClass(cssRulesLabel, "memberRow").
                 getElementsByClassName("memberValueCell").item(0);
 
-            FBTest.compare("CSSPageRule", cssRuleValue.textContent.trim(), "Rule must be displayed as CSSPageRule");
+            FBTest.compare("CSSPageRule", cssRuleValue.textContent.trim(),
+                "Rule must be displayed as CSSPageRule");
 
             FBTest.testDone("issue6283.DONE");
         });
@@ -12,7 +12,7 @@ function runTest()
                 "InspectIndomPanel", function()
             {
-                // xxxHonza, xxxsz: hack that fixes this text on Mac. The panel can 
+                // xxxHonza, xxxsz: hack that fixes this test on Mac. The panel can
                 // be selected asynchronously.
                 setTimeout(function() {

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-mozext/firebug.git



More information about the Pkg-mozext-commits mailing list